"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.options = exports.defaultOptions = exports.oakTypes = exports.oakRpc = void 0;
const utils_1 = require("@open-web3/orml-type-definitions/utils");
const automationTime = {
    rpc: {
        automationTime: {
            generateTaskId: {
                description: 'Getting task ID given account ID and provided ID',
                params: [
                    { name: 'accountId', type: 'AccountId' },
                    { name: 'providedId', type: 'Text' },
                ],
                type: 'Hash',
            },
            getTimeAutomationFees: {
                description: 'Retrieve automation fees',
                params: [
                    { name: 'action', type: 'AutomationAction' },
                    { name: 'executions', type: 'u32' },
                ],
                type: 'Balance',
            },
            calculateOptimalAutostaking: {
                description: 'Calculate the optimal period to restake',
                params: [
                    { name: 'principal', type: 'i128' },
                    { name: 'collator', type: 'AccountId' },
                ],
                type: 'AutostakingResult',
            },
            getAutoCompoundDelegatedStakeTaskIds: {
                description: 'Return autocompounding tasks by account',
                params: [
                    { name: 'account_id', type: 'AccountId' },
                ],
                type: 'Vec<Hash>',
            },
        },
    },
    types: {
        AutomationAction: {
            _enum: [
                'Notify',
                'NativeTransfer',
                'XCMP',
                'AutoCompoundDelgatedStake'
            ],
        },
        AutostakingResult: {
            period: 'i32',
            apy: 'f64',
        },
    },
};
const xcmpHandler = {
    rpc: {
        xcmpHandler: {
            crossChainAccount: {
                description: 'Find xcmp account id',
                params: [
                    { name: 'accountId', type: 'AccountId32' }
                ],
                type: 'AccountId32',
            },
            fees: {
                description: 'Determine fees for a scheduled xcmp task',
                params: [
                    { name: 'encodedXt', type: 'Bytes' },
                ],
                type: 'u64',
            },
        },
    },
    types: {},
};
const definitions = {
    automationTime,
    xcmpHandler,
};
exports.oakRpc = (0, utils_1.jsonrpcFromDefs)(definitions);
exports.oakTypes = (0, utils_1.typesFromDefs)(definitions);
exports.defaultOptions = {
    types: exports.oakTypes,
    rpc: exports.oakRpc,
};
const options = ({ types = {}, rpc = {}, typesBundle = {}, ...otherOptions } = {}) => ({
    rpc: {
        ...rpc,
        ...exports.oakRpc
    },
    types: {
        ...types,
        ...exports.oakTypes
    },
    ...otherOptions
});
exports.options = options;
//# sourceMappingURL=index.js.map